==> mtalg-1.1.1.tar.gz: mtalg-1.1.1/README.md <==
# ![](https://github.com/WWakker/mtalg/raw/master/mtalg/__res/_MTA.png) *mtalg* — Multithreaded Algebra 

[![version](https://img.shields.io/badge/version-1.1.1-success.svg)](https://github.com/WWakker/mtalg)
[![PyPI Latest Release](https://img.shields.io/pypi/v/mtalg.svg)](https://pypi.org/project/mtalg/)
[![build_test](https://github.com/WWakker/mtalg/actions/workflows/build_test.yml/badge.svg)](https://github.com/WWakker/mtalg/actions?query=workflow%3A%22build+and+test%22++)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=WWakker_mtalg&metric=alert_status)](https://sonarcloud.io/summary/overall?id=WWakker_mtalg)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=WWakker_mtalg&metric=coverage)](https://sonarcloud.io/summary/overall?id=WWakker_mtalg)
[![Security](https://snyk-widget.herokuapp.com/badge/pip/mtalg/badge.svg)](https://snyk.io/vuln/pip:mtalg)
[![CodeQL](https://github.com/WWakker/mtalg/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/WWakker/mtalg/actions/workflows/codeql-analysis.yml)
[![License](https://img.shields.io/pypi/l/mtalg.svg)](https://github.com/WWakker/mtalg/blob/master/LICENSE.txt)
[![Downloads](https://pepy.tech/badge/mtalg)](https://pepy.tech/project/mtalg)
[![Run on Repl.it](https://repl.it/badge/github/wwakker/mtalg)](https://replit.com/@lucamingarelli/Try-mtalg#main.py)


## About

***mtalg*** is a package for multithreaded algebra and random number generation.

## Installation
The library can be install via pip as:

`pip install mtalg`

## Documentation

- https://mtalg.readthedocs.io/en/latest/

## Authors
[Wouter Wakker](https://github.com/WWakker) 
and [Luca Mingarelli](https://github.com/LucaMingarelli), 
2021

[![Python](https://img.shields.io/static/v1?label=made%20with&message=Python&color=blue&style=for-the-badge&logo=Python&logoColor=white)](#)

==> mtalg-1.1.2.tar.gz: mtalg-1.1.2/README.md <==
# ![](https://github.com/WWakker/mtalg/raw/master/mtalg/__res/_MTA.png) *mtalg* — Multithreaded Algebra 

[![version](https://img.shields.io/badge/version-1.1.2-success.svg)](https://github.com/WWakker/mtalg)
[![PyPI Latest Release](https://img.shields.io/pypi/v/mtalg.svg)](https://pypi.org/project/mtalg/)
[![build_test](https://github.com/WWakker/mtalg/actions/workflows/build_test.yml/badge.svg)](https://github.com/WWakker/mtalg/actions?query=workflow%3A%22build+and+test%22++)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=WWakker_mtalg&metric=alert_status)](https://sonarcloud.io/summary/overall?id=WWakker_mtalg)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=WWakker_mtalg&metric=coverage)](https://sonarcloud.io/summary/overall?id=WWakker_mtalg)
[![Security](https://snyk-widget.herokuapp.com/badge/pip/mtalg/badge.svg)](https://snyk.io/vuln/pip:mtalg)
[![CodeQL](https://github.com/WWakker/mtalg/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/WWakker/mtalg/actions/workflows/codeql-analysis.yml)
[![License](https://img.shields.io/pypi/l/mtalg.svg)](https://github.com/WWakker/mtalg/blob/master/LICENSE.txt)
[![Downloads](https://pepy.tech/badge/mtalg)](https://pepy.tech/project/mtalg)
[![Run on Repl.it](https://repl.it/badge/github/wwakker/mtalg)](https://replit.com/@lucamingarelli/Try-mtalg#main.py)


## About

***mtalg*** is a package for multithreaded algebra and random number generation.

## Installation
The library can be install via pip as:

`pip install mtalg`

## Documentation

- https://mtalg.readthedocs.io

## Authors
[Wouter Wakker](https://github.com/WWakker) 
and [Luca Mingarelli](https://github.com/LucaMingarelli), 
2021

[![Python](https://img.shields.io/static/v1?label=made%20with&message=Python&color=blue&style=for-the-badge&logo=Python&logoColor=white)](#)
